@@ -473,6 +473,10 @@ class ChatSession:
         if os.path.exists("action.jsonl"):
             os.remove("action.jsonl")
 
+        # store the message as 'raw_user_input' in workflow_context. This is useful in agentic mode
+        # when command implementations want to get the exact message that user entered (no refinement)
+        self._current_workflow.context['raw_user_message'] = message
+
         refined_user_query = self._refine_user_query(message, self.conversation_history)
 
         from fastworkflow.workflow_agent import build_query_with_next_steps
